Installation
============

There are different ways to install DDSIM on your system.
Depending whether you want to use the simulator for your quantum simulations or want to actually develop DDSIM itself, please the respective docs below.

.. toctree::
   :maxdepth: 2

   install/Users
   install/Developers